summaryrefslogtreecommitdiffstats
path: root/unotools/source/config/configpathes.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'unotools/source/config/configpathes.cxx')
-rw-r--r--unotools/source/config/configpathes.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/unotools/source/config/configpathes.cxx b/unotools/source/config/configpathes.cxx
index 6a583ba92d63..8973e63cc8f5 100644
--- a/unotools/source/config/configpathes.cxx
+++ b/unotools/source/config/configpathes.cxx
@@ -124,7 +124,7 @@ sal_Bool splitLastFromConfigurationPath(OUString const& _sInPath,
{
nPos = _sInPath.lastIndexOf('/',nPos);
}
- else // defined behavior for invalid pathes
+ else // defined behavior for invalid paths
{
nStart = 0, nEnd = _sInPath.getLength();
nPos = -1;
@@ -205,7 +205,7 @@ sal_Int32 lcl_findPrefixEnd(OUString const& _sNestedPath, OUString const& _sPref
sal_Int32 nPrefixLength = _sPrefixPath.getLength();
OSL_ENSURE(nPrefixLength == 0 || _sPrefixPath[nPrefixLength-1] != '/',
- "Cannot handle slash-terminated prefix pathes");
+ "Cannot handle slash-terminated prefix paths");
sal_Bool bIsPrefix;
if (_sNestedPath.getLength() > nPrefixLength)